@@ -4,7 +4,7 @@ from abc import abstractmethod
 class Abstract:
 
     @abstractmethod
-    def get_main_content(self):  # call once
+    def get_content(self):  # call once
         pass
 
     @abstractmethod
@@ -23,8 +23,8 @@ class Abstract:
         return []
 
     # @abstractmethod
-    def get_archive_name(self) -> str:
-        pass
+    # def get_archive_name(self) -> str:
+    #     pass
 
     #  for chapters selected by manual (cli)
     @abstractmethod
