@@ -1,8 +1,10 @@
 import json
+import os
 import re
 from abc import ABC
-from sys import stderr
 from logging import info, warning, error
+from os import path
+from sys import stderr
 from typing import Tuple
 
 from .base_classes import (
@@ -38,6 +40,7 @@ class Provider(Base, Abstract, Static, Callbacks, ArchiveName, ABC):
     _volume = None
     _show_chapter_info = False
     _save_chapter_info = False
+    _save_manga_info = False
     _debug = False
     _override_name = ''
 
@@ -64,14 +67,24 @@ class Provider(Base, Abstract, Static, Callbacks, ArchiveName, ABC):
         self._zero_fill = params.get('zero_fill')
         self._with_manga_name = params.get('with_manga_name')
         self._simulate = params.get('simulate')
-        self._show_chapter_info = params.get('show_current_chapter_info', False)
-        self._save_chapter_info = params.get('save_current_chapter_info', False)
+        self._show_chapter_info = params.get('show_chapter_info', False)
+        self._save_chapter_info = params.get('save_chapter_info', False)
+        self._save_manga_info = params.get('save_manga_info', False)
         self._debug = params.get('debug', False)
         self._override_name = self._params.get('override_archive_name')
         if self._with_manga_name and self._override_name:
             raise RuntimeError('Conflict of parameters. Please use only --with-manga-name, or --override-archive-name')
         self._fill_arguments(params.get('arguments') or [])
 
+        # todo: remove it for version 1.25
+        if params.get('show_current_chapter_info'):
+            warning('Deprecated. Please, use --show-chapter-info instead')
+            self._show_chapter_info = True
+
+        if params.get('save_current_chapter_info'):
+            warning('Deprecated. Please, use --save-chapter-info instead')
+            self._save_chapter_info = True
+
     def process(self, url, params=None):  # Main method
         self._params['url'] = url
         params = params if isinstance(params, dict) else {}
@@ -110,6 +123,19 @@ class Provider(Base, Abstract, Static, Callbacks, ArchiveName, ABC):
 
         info('User-agent: "%s"' % __ua)
 
+        if self._save_manga_info:
+            details = self.manga_details()
+            if details is not None:
+                manga_info_path = path.abspath(path.join(self.get_archive_path()[0], os.pardir))
+                path.isdir(manga_info_path) or os.makedirs(manga_info_path)
+
+                with open(path.join(manga_info_path, 'info.json'), 'w') as manga_info_file:
+                    manga_info_file.write(json.dumps(self.manga_details()))
+
+            else:
+                warning('No manga details was found!')
+                warning('Possibly the provider has not yet been implemented to get this information')
+
         self.loop_chapters()
 
     def _check_archive(self):
@@ -170,6 +196,14 @@ class Provider(Base, Abstract, Static, Callbacks, ArchiveName, ABC):
             if self._save_chapter_info:
                 self._archive.write_file('info.json', json.dumps(self.chapter))
 
+            chapter_info = self.chapter_details(self.chapter)
+            if self._save_chapter_info:
+                if chapter_info is not None:
+                    self._archive.write_file('eduhoribe.json', json.dumps(chapter_info))
+                else:
+                    warning('No chapter details was found!')
+                    warning('Possibly the provider has not yet been implemented to get this information')
+
             self._call_files_progress_callback()
 
             self._multi_thread_save(self._storage['files'])
@@ -304,3 +338,21 @@ class Provider(Base, Abstract, Static, Callbacks, ArchiveName, ABC):
         for k in cookies:
             self._storage['cookies'][k] = cookies[k]
             self.http().cookies[k] = cookies[k]
+
+    # region specified data for eduhoribe/comic-builder (see https://github.com/manga-py/manga-py/issues/347)
+
+    def chapter_details(self, chapter) -> dict:
+        """
+        Following the pattern specified in
+        https://github.com/eduhoribe/comic-builder/blob/goshujin-sama/samples/chapter-metadata-sample.json
+        """
+        pass
+
+    def manga_details(self) -> dict:
+        """
+        Following the pattern specified in
+        https://github.com/eduhoribe/comic-builder/blob/goshujin-sama/samples/comic-metadata-sample.json
+        """
+        pass
+
+    # endregion
