@@ -12,7 +12,7 @@ class MangaNeloCom(Provider, Std):
         return self.re.search(self.chapter_re, self.get_chapter())\
             .group(1).replace('.', '-')
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}%s{}' % self._prefix)
 
     def get_manga_name(self) -> str:
