@@ -10,7 +10,7 @@ class MngCowCo(AuthroneCom, Std):
             self.chapter
         ).group(1).replace('.', '-')
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}/')
 
     def get_manga_name(self) -> str:
