@@ -9,7 +9,7 @@ class PsychoPlayCo(Provider, Std):
         idx = self.re.search('/read/[^/]+/([^/]+)', ch)
         return idx.group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/series/{}')
 
     def get_manga_name(self) -> str:
