@@ -8,7 +8,7 @@ class ReadPtscansCom(Provider, Std):
         return self.re.search(r'.+?(\d+(?:\.\d+)?)\s*$', chapter)\
             .group(1).replace('.', '-')
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/series/{}')
 
     def get_manga_name(self) -> str:
